@@ -1,7 +1,8 @@
 from enum import Enum
-from pydantic import BaseModel
 from typing import Optional, List
 
+from zen_dash.support import BaseUpdate
+
 
 
 
@@ -9,11 +10,11 @@ class Style(Enum):
   JS= "javascript"
   STYLE ="css"
 
-class CustomScript(BaseModel):
+class CustomScript(BaseUpdate):
   url: Optional[str]
   text: Optional[str]
   type: Style
 
 
-class CustomScripts(BaseModel):
+class CustomScripts(BaseUpdate):
   scripts: List[CustomScript]
